<?php
namespace Neuron\Person\Controller;
use Neuron\Person\Relations;
use Neuron\Person\Relation as RelationModel;
use Neuron\Generic\Result;

class Relation extends \Neuron\Person\Controller {

    public function listAction() {
        $result = new Result();
        $session = $this->getSession()->get();
        $post = $this->getRest()->getParameters();


        $personId = $post['subject'];
        try {
            $relations = new Relations(RelationModel\Storage::factory($this->getDb(),$this->getConfig()));
            $dataRelations = $relations->load($personId, RelationModel\Storage::LISTBY_SUBJECT);
            $result->data = array(
                'rows' => $dataRelations->data['list'],
                'countTotal' => $dataRelations->data['countTotal'],
            );
        } catch (\Exception $th) {
            $result->code = 500;
            $result->info = $this->translate("failed loading relations");
        }

        $requestPost = array(
			'guid' => '',
			'code' => '',
			'info' => '',
			'data' => $post
		); 
		
		$responseResult = array(
			'guid' => $result->guid,
			'code' => $result->code,
			'info' => $result->info,
			'data' => $result->data
		); 
		
		$logparam['subject'] = 'API PERSON LOAD FAMILY';
		$logparam['identity'] = $personId ? $personId : '';
		$logparam['user'] = $session['user_id'] ? $session['user_id'] : '';
		$logparam['description'] = 'Log proses api person load family';
		$logparam['request'] = json_encode($requestPost);
		$logparam['response'] = json_encode($responseResult);
		
		$this->writeLogAction($logparam);
		
        return $this->getREST()->getResponse($result);
    }

    public function loadAction() {
        $result = new Result();
        $session = $this->getSession()->get();
        $post = $this->getRest()->getParameters();


        $relation_id = $post['relation_id'];
        try {
            $relation = new RelationModel(RelationModel\Storage::factory($this->getDb(),$this->getConfig()));
            $relation->load($relation_id, RelationModel\Storage::LOADBY_ID);
            $result->data = array_merge($relation->pull(), $relation->person()->pull(), array('relation_status_name'=>$relation->relation_status_name));
            
        } catch (\Exception $th) {
            $result->code = 500;
            $result->info = $this->translate("failed loading relation");
        }

        $requestPost = array(
			'guid' => '',
			'code' => '',
			'info' => '',
			'data' => $post
		); 
		
		$responseResult = array(
			'guid' => $result->guid,
			'code' => $result->code,
			'info' => $result->info,
			'data' => $result->data
		); 
		
		$logparam['subject'] = 'API PERSON LOAD FAMILY';
		$logparam['identity'] = $personId ? $personId : '';
		$logparam['user'] = $session['user_id'] ? $session['user_id'] : '';
		$logparam['description'] = 'Log proses person load family';
		$logparam['request'] = json_encode($requestPost);
		$logparam['response'] = json_encode($responseResult);
		
		$this->writeLogAction($logparam);
		
        return $this->getREST()->getResponse($result);
    }

    public function saveAction() {
        $result = new Result();
        $session = $this->getSession()->get();
        $post = $this->getRest()->getParameters();
        
        try {
            $relation = new RelationModel(RelationModel\Storage::factory($this->getDb(),$this->getConfig()));
            $result = $relation->create($post);
        } catch (\Exception $th) {
            $result->code = 500;
            $result->info = $this->translate("failed save relation");
        }
		
		$requestPost = array(
			'guid' => '',
			'code' => '',
			'info' => '',
			'data' => $post
		); 

		$logparam['subject'] = 'PERSON SAVE FAMILY';
		$logparam['identity'] = $this->getSession()->owner();;
		$logparam['datail'] = $result;
		$logparam['description'] = 'Log proses person save family';
		$logparam['request'] = json_encode($requestPost);
		$logparam['response'] = json_encode($result);

		$this->writeLogAction($logparam);
		
        return $this->getREST()->getResponse($result);
    }

    public function deleteAction() {
        $result = new Result();
        $session = $this->getSession()->get();
        $post = $this->getRest()->getParameters();


        $relation_id = $post['relation_id'];
        try {
            $relation = new RelationModel(RelationModel\Storage::factory($this->getDb(),$this->getConfig()));
            $result = $relation->delete($relation_id);
        } catch (\Exception $th) {
            $result->code = 500;
            $result->info = $this->translate("failed loading relation");
        }

        $requestPost = array(
			'guid' => '',
			'code' => '',
			'info' => '',
			'data' => $post
		); 
		
		$responseResult = array(
			'guid' => $result->guid,
			'code' => $result->code,
			'info' => $result->info,
			'data' => $result->data
		); 
		
		$logparam['subject'] = 'API PERSON LOAD FAMILY';
		$logparam['identity'] = $relation_id ? $relation_id : '';
		$logparam['user'] = $session['user_id'] ? $session['user_id'] : '';
		$logparam['description'] = 'Log proses person load family';
		$logparam['request'] = json_encode($requestPost);
		$logparam['response'] = json_encode($responseResult);
		
		$this->writeLogAction($logparam);
		
        return $this->getREST()->getResponse($result);
    }

    public function statusAction(){
        $result = new Result();
        $session = $this->getSession()->get();
        $post = $this->getRest()->getParameters();


        $personId = $post['person_id'];
        try {
            $relations = new Relations(RelationModel\Storage::factory($this->getDb(),$this->getConfig()));
            $dataRelations = $relations->load($personId, RelationModel\Storage::LISTBY_SUBJECT);
            $result->data = array(
                'rows' => $dataRelations->data['list'],
                'countTotal' => $dataRelations->data['countTotal'],
            );
        } catch (\Exception $th) {
            $result->code = 500;
            $result->info = $this->translate("failed loading relations");
        }

        $requestPost = array(
			'guid' => '',
			'code' => '',
			'info' => '',
			'data' => $post
		); 
		
		$responseResult = array(
			'guid' => $result->guid,
			'code' => $result->code,
			'info' => $result->info,
			'data' => $result->data
		); 
		
		$logparam['subject'] = 'API PERSON LOAD STATUS';
		$logparam['identity'] = $personId ? $personId : '';
		$logparam['user'] = $session['user_id'] ? $session['user_id'] : '';
		$logparam['description'] = 'Log proses api person load status';
		$logparam['request'] = json_encode($requestPost);
		$logparam['response'] = json_encode($responseResult);
		
		$this->writeLogAction($logparam);
		
        return $this->getREST()->getResponse($result);
    }

}
