<?php
namespace Neuron\Person\Relation;

use Neuron\Generic\Entity\Map;

class Status extends \Neuron\Generic\Entity\Mapper {
	
	protected $_storage;
	const ERROR_PREFIX = 'PERSON_STATUS-';
	const CACHE_HASH 	= 'person-status';
	
	const DEFAULT_STATUS_ACTIVE 	= 1;

	public function __construct(\Neuron\Person\Relation\Status\Storage\Skeleton $storage, $data = array()) {
		
		$this->_storage = $storage;
		
        parent::__construct(
            $data, 
            array(
                new Map('status_id'),
                new Map('code'),
                new Map('description'),
            ), 
            parent::CASE_INSENSITIVE
        );
	}

	public function listStatus($page = 1, $length = 10, $filter = array()) {
		$result = $this->_storage->listStatus($page, $length, $filter);
		$total = $this->_storage->totalStatus($filter);

		return array('data'=> $result, 'total'=>$total);
	}
	
	public function load($statusId)
	{
		if($data = $this->_storage->load($statusId)){
			$this->push($data);
			return true;
		}else{
			return false;
		}
	}
	public function checkCode($code)
	{
		return $this->_storage->checkCode($code);
	}
	public function save($update = false){
		if ($id = $this->_storage->save($this, $update)) {
			$this->status_id = $id;
			return true;
		  }
		  return false;
	}
	public function saveEx($data = array()){
		$result 		= new \Neuron\Generic\Result();
		if(!isset($data['code']) || empty($data['code'])){
			$result->info 	= "code required!";
			$result->code 	= self::ERROR_PREFIX.'1';
			return $result;
		}
		if(!isset($data['description']) || empty($data['description'])){
			$result->info 	= "description required!";
			$result->code 	= self::ERROR_PREFIX.'2';
			return $result;
		}

		if(isset($data['status_id']) && !empty($data['status_id'])){
			$update 	= true;
		}else{
			$update 	= false;
		}

		@$this->push($data);
		if($this->save($update)){
			$result->data 	= $this->status_id;
			$result->info 	= "Success saving status";
		}else{
			$result->code 	= self::ERROR_PREFIX.'3';
			$result->info 	= "Failed saving status";
		}

		return $result;
	}

	public function remove($statusId)
	{
		try {
			if($this->_storage->countPersonByStatus($statusId) > 0){
				return array('success'=>false, 'message'=> 'this being used by people');
			}
			if($this->_storage->remove($statusId)){
				return array('success'=>true, 'message'=> 'status removed');
			}
			return array('success'=>false, 'message'=> 'error');
		} catch (\Throwable $th) {
			return array('success'=>false, 'message'=> 'error');
		}
		
	}

}